require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_clocalfileshare',
  dscmeta_resource_friendly_name: 'cLocalFileShare',
  dscmeta_resource_name: 'cLocalFileShare',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'cLocalFileShare',
  dscmeta_module_version: '1.0.1',
  docs: 'The DSC cLocalFileShare resource type.
         Automatically generated from version 1.0.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_changeaccess: {
      type: 'Optional[Array[String]]',
      desc: 'Indicates which accounts are granted Change permission to access the share.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_noaccess: {
      type: 'Optional[Array[String]]',
      desc: 'Indicates which accounts are denied access to the share.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Absent', 'Present']]",
      desc: 'Indicates if the share exists. Set this property to Absent to ensure that the share does not exist. Setting it to Present (the default value) ensures that the share exists.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_readaccess: {
      type: 'Optional[Array[String]]',
      desc: 'Indicates which accounts are granted Read permission to access the share.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Indicates an optional description for the share.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_concurrentuserlimit: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Indicates the number of users allowed to concurrently use the share. To set the limit at the maximum number, set this property to zero.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Indicates the name of the share.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_fullaccess: {
      type: 'Optional[Array[String]]',
      desc: 'Indicates which accounts are granted Full Control permission to access the share.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'Indicates the path to the location of the folder to share.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
